dj_anonymizer [![Build Status](https://github.com/preply/dj_anonymizer/actions/workflows/test.yml/badge.svg)](https://travis-ci.com/preply/dj_anonymizer) [![codecov.io](https://codecov.io/github/preply/dj_anonymizer/coverage.svg?branch=master)](https://codecov.io/github/preply/dj_anonymizer?branch=master) [![PyPI version](https://badge.fury.io/py/dj-anonymizer.svg)](https://badge.fury.io/py/dj_anonymizer)
==================================

dj_anonymizer is a utility designed to anonymize production databases with various types of mock data, specifically designed for use within Django projects.

Project works with Django 4.2 or higher and Python 3.8 or higher.

Documentation
==================================
[https://dj-anonymizer.readthedocs.io/en/latest/](https://dj-anonymizer.readthedocs.io/en/latest/)
